This crate contains kube-rs compatible bindings for Kubernetes custom resources for the iot.eclipse.org group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
iot.eclipse.org/v1alpha1
DittoHawkbit